#include <cstdio>
#include <cstdlib>

// ===========================================================================
// Constantes.

const struct { int dl, dc; } DEP[4] = {
    {0,1}, {0,-1}, {-1,0}, {1,0}
};

// ===========================================================================
// Donnes globales.

int W, H;
bool map[1000][1000];

// ===========================================================================
// Fonctions d'analyse de la grille.

bool isWhite(int l, int c)
{
    bool col = map[l][c];
    
    for (int v = 0; v < 4; v++) {
        int nc = c + DEP[v].dc;
        int nl = l + DEP[v].dl;
        if (nl >= 0 && nl < H && nc >= 0 && nc < W)
            col ^= map[nl][nc];
    }
    
    return !col;
}

bool mapSolved()
{
    for (int l = 0; l < H; l++)
        for (int c = 0; c < W; c++)
            if (isWhite(l, c))
                return false;
    
    return true;
}

// ===========================================================================
// Fonctions d'affichage des solutions.

void printMap()
{
    for (int l = 0; l < H; l++) {
        for (int c = 0; c < W; c++)
            putchar(map[l][c] ? '#' : '_');
        putchar('\n');
    }
}

void writeSolution()
{
    char fstr[42];
    sprintf(fstr, "grille-%02dx%02d.txt", W, H);
    freopen(fstr, "w", stdout);
    printMap();
}

// ===========================================================================
// Algorithme de recherche d  Mathias Hiron.
// Sa complexit est en O(W*H*2^H).

void completeMap()
{
    for (int l = 1; l < H; l++) {
        for (int c = 0; c < W; c++) {
            map[l][c] = false;
            map[l][c] = isWhite(l - 1, c);
        }
    }
}

void hironate(int c)
{
    if (c >= W) {
        completeMap();
        if (mapSolved()) {
            printMap();
            writeSolution();
            exit(0);
        }
    } else {
        map[0][c] = true;
        hironate(c + 1);
        map[0][c] = false;
        hironate(c + 1);
    }
}

// ===========================================================================
// Fonction principale.

int main()
{
    scanf("%d%d", &W, &H);    
    hironate(0);
    printf("Aucune solution ?\n");
    return 0;
}
