#include <cstdio>
#include <cstdlib>
#include <cstring>

// ===========================================================================
// Constantes.

const int MAX_MAP_SIZE = 42;

const struct { int dx, dy; } DEP[4] = {
    {1, 0}, {-1, 0}, {0, 1}, {0, -1}
};

// ===========================================================================
// Donnes globales.

int n;
int x, y;
int map[MAX_MAP_SIZE][MAX_MAP_SIZE];
int nbVisits[MAX_MAP_SIZE][MAX_MAP_SIZE];
char way[MAX_MAP_SIZE * MAX_MAP_SIZE];

// ===========================================================================
// Fonctions de traitement de la grille.

bool mapClean()
{
    for (int i = 0; i < n; i++)
        for (int j = 0; j < n; j++)
            if (map[i][j] != 1)
                return false;
    
    return true;
}

void resetMap()
{
    for (int l = 0; l < n; l++) {
        for (int c = 0; c < n; c++) {
            nbVisits[c][l] = 0;
            map[c][l] = 0;
        }
    }
    
    x = 0;
    y = n - 1;
    way[0] = 0;
    updatePos(x, y);
}

void updatePos(int nx, int ny)
{
    if (nx < 0 || nx >= n || ny < 0 || ny >= n) {
        printf("Sortie !!!\n");
        exit(-1);
    }
    
    nbVisits[nx][ny]++;
    map[nx][ny] ^= 1;
    
    for (int v = 0; v < 4; v++) {
        int px = nx + DEP[v].dx;
        int py = ny + DEP[v].dy;
        if (px >= 0 && px < n && py >= 0 && py < n)
            map[px][py] ^= 1;
    }
}

// ===========================================================================
// Fonctions d'affichage.

void printMap()
{
    system("clear");
    
    for (int l = 0; l < n; l++) {
        for (int c = 0; c < n; c++) {
            if (c == x && l == y) {
                if (map[c][l] == 1)
                    putchar('E');
                else
                    putchar('e');
            } else if (map[c][l] == 1)
                putchar('#');
            else
                putchar('_');
        }
        putchar('\n');
    }
}

void printMapVisits()
{
    for (int l = 0; l < n; l++) {
        for (int c = 0; c < n; c++) {
            if (nbVisits[c][l] % 2 == 0)
                putchar('_');
            else
                putchar('x');
        }
        putchar('\n');
    }
}

void writeSolution()
{
    char fstr[42];
    sprintf(fstr, "grille-%02dx%02d.txt", W, H);
    freopen(fstr, "w", stdout);
    printMapVisits();
}

// ===========================================================================
// Fonction principale.

int main()
{
    printf("Dimension de la grille ? ");
    scanf("%d", &n);
    resetMap();
    
    do {
        char cmd[42];
        printMap();
        scanf("%s", cmd);
        for (int i = 0; i < 42 && cmd[i]; i++)
            switch (cmd[i]) {
                case 'n':
                    updatePos(x, --y);
                    break;
                case 's':
                    updatePos(x, ++y);
                    break;
                case 'e':
                    updatePos(++x, y);
                    break;
                case 'o':
                    updatePos(--x, y);
                    break;
                case '0':
                    resetMap();
                    break;
                default:
                    break;
            }
        strcat(way, cmd);
    } while (!mapClean());
    
    printf("OK\n");
    printf("Chemin : %s.\n", way);
    printMapVisits();
    writeSolution();
    return 0;
}
